==> sqlparser-0.16.0.tar.gz: test/scanner/recognizes_all_tokens_test.dart <==
import 'dart:convert';
import 'dart:ffi';

import 'package:test/test.dart';
import 'package:sqlite3/open.dart';
import 'package:ffi/ffi.dart';

import 'package:sqlparser/src/reader/tokenizer/token.dart';

typedef sqlite3_keyword_count_native = Int32 Function();
typedef sqlite3_keyword_count = int Function();

typedef sqlite3_keyword_name_native = Int32 Function(
    Int32, Pointer<Pointer<Uint8>>, Pointer<Int32>);
typedef sqlite3_keyword_name = int Function(
    int, Pointer<Pointer<Uint8>>, Pointer<Int32>);

void main() {
  String? skip;
  late DynamicLibrary library;

  try {
    library = open.openSqlite();

    // Some platforms have sqlite3, but no sqlite3_keyword_count
    library.lookup('sqlite3_keyword_count');
  } on Object {
    skip = 'sqlite3 is not available in test environment';
  }

  test(
    'recognizes all sqlite tokens',
    () {
      final keywordCount = library.lookupFunction<sqlite3_keyword_count_native,
          sqlite3_keyword_count>('sqlite3_keyword_count')();
      final nameFunction = library.lookupFunction<sqlite3_keyword_name_native,
          sqlite3_keyword_name>('sqlite3_keyword_name');

      final charOut = malloc<Pointer<Uint8>>();
      final lengthOut = malloc<Int32>();

      final missingNames = <String>[];

      for (var i = 0; i < keywordCount; i++) {
        nameFunction(i, charOut, lengthOut);

        final bytes = charOut.value.asTypedList(lengthOut.value);
        final name = utf8.decode(bytes);

        if (!keywords.containsKey(name)) {
          missingNames.add(name);
        }
      }

      missingNames.sort();

      malloc.free(charOut);
      malloc.free(lengthOut);

      expect(missingNames, isEmpty);
    },
    skip: skip,
  );
}

==> sqlparser-0.17.0.tar.gz: test/scanner/recognizes_all_tokens_test.dart <==
@TestOn('vm')
import 'dart:convert';
import 'dart:ffi';

import 'package:test/test.dart';
import 'package:sqlite3/open.dart';
import 'package:ffi/ffi.dart';

import 'package:sqlparser/src/reader/tokenizer/token.dart';

typedef SqliteKeywordCountNative = Int32 Function();
typedef SqliteKeywordCount = int Function();

typedef SqliteKeywordNameNative = Int32 Function(
    Int32, Pointer<Pointer<Uint8>>, Pointer<Int32>);
typedef SqliteKeywordName = int Function(
    int, Pointer<Pointer<Uint8>>, Pointer<Int32>);

void main() {
  String? skip;
  late DynamicLibrary library;

  try {
    library = open.openSqlite();

    // Some platforms have sqlite3, but no sqlite3_keyword_count
    library.lookup('sqlite3_keyword_count');
  } on Object {
    skip = 'sqlite3 is not available in test environment';
  }

  test(
    'recognizes all sqlite tokens',
    () {
      final keywordCount =
          library.lookupFunction<SqliteKeywordCountNative, SqliteKeywordCount>(
              'sqlite3_keyword_count')();
      final nameFunction =
          library.lookupFunction<SqliteKeywordNameNative, SqliteKeywordName>(
              'sqlite3_keyword_name');

      final charOut = malloc<Pointer<Uint8>>();
      final lengthOut = malloc<Int32>();

      final missingNames = <String>[];

      for (var i = 0; i < keywordCount; i++) {
        nameFunction(i, charOut, lengthOut);

        final bytes = charOut.value.asTypedList(lengthOut.value);
        final name = utf8.decode(bytes);

        if (!keywords.containsKey(name)) {
          missingNames.add(name);
        }
      }

      missingNames.sort();

      malloc.free(charOut);
      malloc.free(lengthOut);

      expect(missingNames, isEmpty);
    },
    skip: skip,
  );
}
